# DBX deploy bundle

This bundle allows you to deploy notebooks along with custom code to Databricks. It is part of the [Daipe Framework](https://www.daipe.ai).  

## Resources

* [Documentation](https://docs.daipe.ai/deploy-demo-project/)
